==> haskell-kvitable-1.0.3.0-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-kvitable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kvitable
version:              1.0.3.0
visibility:           public
id:                   kvitable-1.0.3.0-A8hUESqOI04GKhg2fn4AP6
key:                  kvitable-1.0.3.0-A8hUESqOI04GKhg2fn4AP6
license:              ISC
copyright:            Kevin Quick, 2021-2022
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/kvitable
synopsis:             Key/Value Indexed Table container and formatting library
description:

    Allows creation of a table from a set of of Key+Value Indices.
    This differs from the standard '\''Map'\'' structure in that the '\''Map'\''
    simply indexes by value but the KVI table indexes by a
    heterogeneous list of keys along with their associated values.
    This effectively creates an N-dimensional table, where
    @N=Product(Count(Values[key]))@.  The table contents can be sparse.

    This library also provides the ability to format multi-dimensional
    data in a table presentation.  The table is automatically formatted
    and can be output in a number of different styles (ascii, html,
    etc.)

    Multi-dimensional data is more difficult to represent than simple
    two-dimensional data; this package provides the ability to select
    which dimensions should be represented as sub-rows and which
    dimensions should be represented as sub-columns.  See the README
    for examples

category:             Text
abi:                  a7703dfc6445cc86199c086abe8b60a7
exposed:              True
exposed-modules:
    Data.KVITable Data.KVITable.Render Data.KVITable.Render.ASCII
    Data.KVITable.Render.HTML

import-dirs:          /usr/lib/ghc-9.4.8/site-local/kvitable-1.0.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/kvitable-1.0.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/kvitable-1.0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kvitable
hs-libraries:         HSkvitable-1.0.3.0-A8hUESqOI04GKhg2fn4AP6
depends:
    base-4.17.2.1 containers-0.6.7
    lucid-2.11.20230408-4jBnvRh9uDD20DjIiRHVMa
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    prettyprinter-1.7.1-IL3WuZoemUT4csWPo7vzAj text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-kvitable/html/kvitable.haddock
haddock-html:         /usr/share/doc/haskell-kvitable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-kvitable-1.0.3.0-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-kvitable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kvitable
version:              1.0.3.0
visibility:           public
id:                   kvitable-1.0.3.0-Ij6s2rwes5bGaOCFiwBEDP
key:                  kvitable-1.0.3.0-Ij6s2rwes5bGaOCFiwBEDP
license:              ISC
copyright:            Kevin Quick, 2021-2022
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/kvitable
synopsis:             Key/Value Indexed Table container and formatting library
description:

    Allows creation of a table from a set of of Key+Value Indices.
    This differs from the standard '\''Map'\'' structure in that the '\''Map'\''
    simply indexes by value but the KVI table indexes by a
    heterogeneous list of keys along with their associated values.
    This effectively creates an N-dimensional table, where
    @N=Product(Count(Values[key]))@.  The table contents can be sparse.

    This library also provides the ability to format multi-dimensional
    data in a table presentation.  The table is automatically formatted
    and can be output in a number of different styles (ascii, html,
    etc.)

    Multi-dimensional data is more difficult to represent than simple
    two-dimensional data; this package provides the ability to select
    which dimensions should be represented as sub-rows and which
    dimensions should be represented as sub-columns.  See the README
    for examples

category:             Text
abi:                  2469c52d6b76635c5dfb232ea92c1e7a
exposed:              True
exposed-modules:
    Data.KVITable Data.KVITable.Render Data.KVITable.Render.ASCII
    Data.KVITable.Render.HTML

import-dirs:          /usr/lib/ghc-9.4.8/site-local/kvitable-1.0.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/kvitable-1.0.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/kvitable-1.0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kvitable
hs-libraries:         HSkvitable-1.0.3.0-Ij6s2rwes5bGaOCFiwBEDP
depends:
    base-4.17.2.1 containers-0.6.7
    lucid-2.11.20230408-HKe6Wv8xdWQzghUUMBQqJ
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    prettyprinter-1.7.1-4Mn04lWp3HTA5zh48zv2n2 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-kvitable/html/kvitable.haddock
haddock-html:         /usr/share/doc/haskell-kvitable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
